Facebook Client
===============

Facebook Client handles all Facebook related actions. 


.. autoclass:: fbchat_muqit.FacebookClient
   :members: __init__, uid, name
   :undoc-members:
   :show-inheritance:



Overview
_________

This FacebookClient is seperated from the Messenger Client. ``FacebookClient`` is not used directly instead used as a base class for the main ``Client`` class for maintainabilty. 



